@@ -5,6 +5,7 @@ import json
 import template
 from hcli import api
 from hcli import home
+from hcli import secondaryhome
 from hcli import document
 from hcli import command
 from hcli import option
@@ -20,8 +21,9 @@ def connector(plugin_path=None):
         config.parse_template(template.Template())
 
         # We setup the HCLI Connector
-        server = falcon.API()
+        server = falcon.App()
         server.add_route(home.HomeController.route, api.HomeApi())
+        server.add_route(secondaryhome.SecondaryHomeController.route, api.SecondaryHomeApi())
         server.add_route(document.DocumentController.route, api.DocumentApi())
         server.add_route(command.CommandController.route, api.CommandApi())
         server.add_route(option.OptionController.route, api.OptionApi())
